15.136. cdist-type__timezone(7) — cdist 4.10.4 documentation

# 15.136. cdist-type__timezone(7)

## 15.136.1. NAME

cdist-type__timezone - Allows one to configure the desired localtime timezone.

## 15.136.2. DESCRIPTION

This type creates a symlink (/etc/localtime) to the selected timezone (which should be available in /usr/share/zoneinfo).

## 15.136.3. REQUIRED PARAMETERS

None.

## 15.136.4. OPTIONAL PARAMETERS

None.

## 15.136.5. EXAMPLES

    #Set up Europe/Andorra as our timezone.
    __timezone Europe/Andorra

    #Set up US/Central as our timezone.
    __timezone US/Central

## 15.136.6. AUTHORS

Ramon Salvadó <rsalvado--@--gnuine--dot--com>

## 15.136.7. COPYING

Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).